@@ -51,11 +51,11 @@ def main(inputfile, outputfile, environment):
     os.makedirs(f'{path_tikz}/tikz', exist_ok=True)
     path_main = os.path.join(f'{path_tikz}/tikz', 'main.tex')
     
-    files = []
     try:
         extract_tex_env(inputfile, outputfile, environment)
         try:
-            files = [f for f in os.listdir(f'./tikz') if os.path.isfile(f)]
+            global files
+            files = [f for f in os.listdir(f'{path_tikz}/tikz') if os.path.isfile(f)]
         except:
             click.echo("Faild to list files.")
     except:
